<?php
/* Copyright (C) 2016		 Oscss-Shop       <support@oscss-shop.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 * or see http://www.gnu.org/
 */

/**
 * 	\defgroup   lcr      Module LCR
 * 	\brief      Module pour gerer les traites
 */
/**
 * 	\file       htdocs/includes/modules/modlcr.class.php
 * 	\ingroup    lcr
 * 	\brief      Fichier de description et activation du module de click to Dial
 * 	\author     Oscss-Shop <mail support@oscss-shop.fr>
 * 	\version    $Id: modCalling.php,v 1.56 2012/06/10 15:28:01 oscim Exp $
 */

/**
  \class      modCalling
  \brief      Classe de description et activation du module de Click to Dial
 */
global $conf;
if (isset($conf->framework) && $conf->framework->enabled) {
    dol_include_once('/framework/class/dolmodexts.class.php');
    dol_include_once('/lcr/class/update.class.php');
    global $langs;
    $langs->load('framework');
    class_alias('DolModExts', 'DolibarrModuleslcr');
} else class_alias('DolibarrModules', 'DolibarrModuleslcr');

class modlcr extends DolibarrModuleslcr
{

    /**
     *   \brief      Constructeur. Definit les noms, constantes et boites
     *   \param      DB      handler d'acces base
     */
    function modlcr($DB)
    {
        global $langs, $conf;

        $this->db     = $DB;
        $this->numero = 121001;
        $this->name   = preg_replace('/^mod/i', '', get_class($this));

        if (isset($conf->framework) && $conf->framework->enabled) {
            $this->GetFileBuild();
            $this->loadOscssConf();
            // Boites
            $this->loadbox('/lcr/core/boxes/', '\CORE\LCR\\');
        } else
        // Boites
            $this->boxes = array();


        $langs->load($this->name);

        $this->family = "financial";
        $this->label  = $langs->trans(preg_replace('/^mod/i', '', get_class($this)));

        $this->description = "Gestion des LCR";

        // Data directories to create when module is enabled
        $this->dirs = array("/lcr");

        $this->phpmin                = array(5, 3);
        $this->need_dolibarr_version = array(9, 0);

        // Dependencies
        $this->depends      = array('modBanque');
//         $this->requiredby   = array();
//         $this->conflictwith = array();


        // Defined all module parts (triggers, login, substitutions, menus, etc...) (0=disable,1=enable)
        $this->module_parts = array('triggers' => 1, 'models' => 1);


        // tabs
        $this->tabs = array(
            'invoice:+lcrtab:lcr:@lcr:/lcr/tab/lcr.php?facid=__ID__',
        );


        // Config pages
        $this->config_page_url = array(dol_buildpath('/lcr/admin/index.php', 1));



        // Permissions
        $r                   = 0;
        $this->rights[$r][0] = $this->numero.$r;
        $this->rights[$r][1] = 'Read withdrawals';
        $this->rights[$r][2] = 'r';
        $this->rights[$r][3] = 1;
        $this->rights[$r][4] = 'bons';
        $this->rights[$r][5] = 'lire';

        $r++;
        $this->rights[$r][0] = $this->numero.$r;
        $this->rights[$r][1] = 'Create/modify a withdrawals';
        $this->rights[$r][2] = 'w';
        $this->rights[$r][3] = 0;
        $this->rights[$r][4] = 'bons';
        $this->rights[$r][5] = 'creer';

        $r++;
        $this->rights[$r][0] = $this->numero.$r;
        $this->rights[$r][1] = 'Send withdrawals to bank';
        $this->rights[$r][2] = 'a';
        $this->rights[$r][3] = 0;
        $this->rights[$r][4] = 'bons';
        $this->rights[$r][5] = 'send';

        $r++;
        $this->rights[$r][0] = $this->numero.$r;
        $this->rights[$r][1] = 'credit/refuse withdrawals';
        $this->rights[$r][2] = 'a';
        $this->rights[$r][3] = 0;
        $this->rights[$r][4] = 'bons';
        $this->rights[$r][5] = 'credit';



        $r++;
        $this->rights[$r][0] = $this->numero.$r;
        $this->rights[$r][1] = 'credit/refuse withdrawals';
        $this->rights[$r][2] = 'a';
        $this->rights[$r][3] = 0;
        $this->rights[$r][4] = 'bons';
        $this->rights[$r][5] = 'configurer';



        // Main menu entries

        $r              = 0;
        $this->menu[$r] = array(
            'fk_menu' => 'fk_mainmenu=bank',
            'type' => 'left',
            'titre' => "StandingOrdersLcr",
            'mainmenu' => 'bank',
            'leftmenu' => 'lcr', // Use 1 if you also want to add left menu entries using this descriptor.
            'url' => '/lcr/index.php?leftmenu=lcr',
            'langs' => 'lcr@lcr',
            'position' => 100 + $r,
            'perms' => '$user->rights->lcr->bons->lire',
            'enabled' => '$conf->lcr->enabled',
            'target' => '',
            'user' => 2
        );

        $r++;
        $this->menu[$r] = array('fk_menu' => 'fk_mainmenu=bank,fk_leftmenu=lcr',
            'type' => 'left',
            'titre' => "NewStandingOrderLcr",
// 													'mainmenu'=>'bank',
// 													'leftmenu'=>'lcr',
            'mainmenu' => '',
            'leftmenu' => '',
            'url' => '/lcr/create.php',
            'langs' => 'lcr@lcr',
            'position' => 200 + $r,
            'perms' => '$user->rights->lcr->bons->lire',
            'enabled' => '$conf->lcr->enabled',
            'target' => '',
            'user' => 2);



        $r++;
        $this->menu[$r] = array('fk_menu' => 'fk_mainmenu=bank,fk_leftmenu=lcr',
            'type' => 'left',
            'titre' => "ListStandingInvoiceDemande",
            'mainmenu' => '',
            'leftmenu' => '', // Use 1 if you also want to add left menu entries using this descriptor.
            'url' => '/lcr/demandes.php',
            'langs' => 'lcr@lcr',
            'position' => 100 + $r,
            'perms' => '$user->rights->lcr->bons->lire',
            'enabled' => '$conf->lcr->enabled',
            'target' => '',
            'user' => 2);


        $r++;
        $this->menu[$r] = array('fk_menu' => 'fk_mainmenu=bank,fk_leftmenu=lcr',
            'type' => 'left',
            'titre' => "Receipts",
//                                     'mainmenu'=>'bank',
//                                     'leftmenu'=>'lcr',		// Use 1 if you also want to add left menu entries using this descriptor.
            'mainmenu' => '',
            'leftmenu' => '',
            'url' => '/lcr/bons.php',
            'langs' => 'lcr@lcr',
            'position' => 100 + $r,
            'perms' => '$user->rights->lcr->bons->lire',
            'enabled' => '$conf->lcr->enabled',
            'target' => '',
            'user' => 2);




        $r++;
        $this->menu[$r] = array('fk_menu' => 'fk_mainmenu=bank,fk_leftmenu=lcr',
            'type' => 'left',
            'titre' => "List",
//                                     'mainmenu'=>'bank',
//                                     'leftmenu'=>'lcr',		// Use 1 if you also want to add left menu entries using this descriptor.
            'url' => '/lcr/liste.php',
            'langs' => 'lcr@lcr',
            'position' => 100 + $r,
            'perms' => '$user->rights->lcr->bons->lire',
            'enabled' => '$conf->lcr->enabled',
            'target' => '',
            'user' => 2);

        $r++;
        $this->menu[$r] = array('fk_menu' => 'fk_mainmenu=bank,fk_leftmenu=lcr',
            'type' => 'left',
            'titre' => "Bills",
//                                     'mainmenu'=>'bank',
//                                     'leftmenu'=>'lcr',		// Use 1 if you also want to add left menu entries using this descriptor.
            'url' => '/lcr/liste_factures.php',
            'langs' => 'lcr@lcr',
            'position' => 100 + $r,
            'perms' => '$user->rights->lcr->bons->lire',
            'enabled' => '$conf->lcr->enabled',
            'target' => '',
            'user' => 2);

        $r++;
        $this->menu[$r] = array('fk_menu' => 'fk_mainmenu=bank,fk_leftmenu=lcr',
            'type' => 'left',
            'titre' => "Rejects",
//                                     'mainmenu'=>'bank',
//                                     'leftmenu'=>'lcr',		// Use 1 if you also want to add left menu entries using this descriptor.
            'url' => '/lcr/rejets.php',
            'langs' => 'lcr@lcr',
            'position' => 100 + $r,
            'perms' => '$user->rights->lcr->bons->lire',
            'enabled' => '$conf->lcr->enabled',
            'target' => '',
            'user' => 2);

        $r++;
        $this->menu[$r] = array('fk_menu' => 'fk_mainmenu=bank,fk_leftmenu=lcr',
            'type' => 'left',
            'titre' => "Statistics",
//                                     'mainmenu'=>'bank',
//                                     'leftmenu'=>'lcr',		// Use 1 if you also want to add left menu entries using this descriptor.
            'url' => '/lcr/stats.php',
            'langs' => 'lcr@lcr',
            'position' => 100 + $r,
            'perms' => '$user->rights->lcr->bons->lire',
            'enabled' => '$conf->lcr->enabled',
            'target' => '',
            'user' => 2);


		/**
          @remarks End loaded config ans auto-config construct
         */
        if (isset($conf->framework) && $conf->framework->enabled) $this->EndLoader();
    }

    /**
     *      \brief      Function called when module is enabled.
     *                  The init function add constants, boxes, permissions and menus (defined in constructor) into Dolibarr database.
     *                  It also creates data directories.
     *      \return     int             1 if OK, 0 if KO
     */
    function init($options = '')
    {
        global $conf, $langs;

        // Permissions
        $this->remove($options);

        $result = $this->load_tables();

        addDocumentModel('crabeLCR', 'invoice');
        addDocumentModel('crabeLCR8', 'invoice');


        // Create extrafields
        include_once DOL_DOCUMENT_ROOT.'/core/class/extrafields.class.php';
        $extrafields = new ExtraFields($this->db);
        $result1=$extrafields->addExtraField('autoLCR', "LCR automatique ?", 'boolean', 1, 3, 'thirdparty');
        
        $sql = array(array(
            'sql' => "ALTER TABLE ".MAIN_DB_PREFIX."lcr_facture_preconfirm ADD date_validation datetime ",
            'ignoreerror' => true
        ));

        return $this->_init($sql, $options);
//         }
    }

    /**
     *      \brief      Function called when module is disabled.
     *                  Remove from database constants, boxes and permissions from Dolibarr database.
     *                  Data directories are not deleted.
     *      \return     int             1 if OK, 0 if KO
     */
    function remove($options = '')
    {
        global $conf;

        delDocumentModel('crabeLCR', 'invoice');
        delDocumentModel('crabeLCR8', 'invoice');
        $sql = array(
        );

        return $this->_remove($sql, $options);
    }
}
